@@ -2,7 +2,7 @@
 
 double sqrt(double x) {
     double ret;
-    asm volatile (
+    __asm__ volatile (
             "vsqrt.f64  %P0, %P1\n"
             : "=w" (ret)
             : "w"  (x));
