@@ -76,15 +76,15 @@
 /******************************************************************************
  DECLARE PRIVATE FUNCTIONS
  ******************************************************************************/
-STATIC void uart_init (pyb_uart_obj_t *self);
-STATIC bool uart_rx_wait (pyb_uart_obj_t *self);
-STATIC void uart_check_init(pyb_uart_obj_t *self);
-STATIC mp_obj_t uart_irq_new (pyb_uart_obj_t *self, byte trigger, mp_int_t priority, mp_obj_t handler);
-STATIC void UARTGenericIntHandler(uint32_t uart_id);
-STATIC void UART0IntHandler(void);
-STATIC void UART1IntHandler(void);
-STATIC void uart_irq_enable (mp_obj_t self_in);
-STATIC void uart_irq_disable (mp_obj_t self_in);
+static void uart_init (pyb_uart_obj_t *self);
+static bool uart_rx_wait (pyb_uart_obj_t *self);
+static void uart_check_init(pyb_uart_obj_t *self);
+static mp_obj_t uart_irq_new (pyb_uart_obj_t *self, byte trigger, mp_int_t priority, mp_obj_t handler);
+static void UARTGenericIntHandler(uint32_t uart_id);
+static void UART0IntHandler(void);
+static void UART1IntHandler(void);
+static void uart_irq_enable (mp_obj_t self_in);
+static void uart_irq_disable (mp_obj_t self_in);
 
 /******************************************************************************
  DEFINE PRIVATE TYPES
@@ -108,11 +108,11 @@ struct _pyb_uart_obj_t {
 /******************************************************************************
  DECLARE PRIVATE DATA
  ******************************************************************************/
-STATIC pyb_uart_obj_t pyb_uart_obj[PYB_NUM_UARTS] = { {.reg = UARTA0_BASE, .baudrate = 0, .read_buf = NULL, .peripheral = PRCM_UARTA0},
+static pyb_uart_obj_t pyb_uart_obj[PYB_NUM_UARTS] = { {.reg = UARTA0_BASE, .baudrate = 0, .read_buf = NULL, .peripheral = PRCM_UARTA0},
                                                       {.reg = UARTA1_BASE, .baudrate = 0, .read_buf = NULL, .peripheral = PRCM_UARTA1} };
-STATIC const mp_irq_methods_t uart_irq_methods;
+static const mp_irq_methods_t uart_irq_methods;
 
-STATIC const mp_obj_t pyb_uart_def_pin[PYB_NUM_UARTS][2] = { {&pin_GP1, &pin_GP2}, {&pin_GP3, &pin_GP4} };
+static const mp_obj_t pyb_uart_def_pin[PYB_NUM_UARTS][2] = { {&pin_GP1, &pin_GP2}, {&pin_GP3, &pin_GP4} };
 
 /******************************************************************************
  DEFINE PUBLIC FUNCTIONS
@@ -168,7 +168,7 @@ bool uart_tx_strn(pyb_uart_obj_t *self, const char *str, uint len) {
  DEFINE PRIVATE FUNCTIONS
  ******************************************************************************/
 // assumes init parameters have been set up correctly
-STATIC void uart_init (pyb_uart_obj_t *self) {
+static void uart_init (pyb_uart_obj_t *self) {
     // Enable the peripheral clock
     MAP_PRCMPeripheralClkEnable(self->peripheral, PRCM_RUN_MODE_CLK | PRCM_SLP_MODE_CLK);
 
@@ -198,7 +198,7 @@ STATIC void uart_init (pyb_uart_obj_t *self) {
 // Waits at most timeout microseconds for at least 1 char to become ready for
 // reading (from buf or for direct reading).
 // Returns true if something available, false if not.
-STATIC bool uart_rx_wait (pyb_uart_obj_t *self) {
+static bool uart_rx_wait (pyb_uart_obj_t *self) {
     int timeout = PYBUART_RX_TIMEOUT_US(self->baudrate);
     for ( ; ; ) {
         if (uart_rx_any(self)) {
@@ -214,7 +214,7 @@ STATIC bool uart_rx_wait (pyb_uart_obj_t *self) {
     }
 }
 
-STATIC mp_obj_t uart_irq_new (pyb_uart_obj_t *self, byte trigger, mp_int_t priority, mp_obj_t handler) {
+static mp_obj_t uart_irq_new (pyb_uart_obj_t *self, byte trigger, mp_int_t priority, mp_obj_t handler) {
     // disable the uart interrupts before updating anything
     uart_irq_disable (self);
 
@@ -235,7 +235,7 @@ STATIC mp_obj_t uart_irq_new (pyb_uart_obj_t *self, byte trigger, mp_int_t prior
     return _irq;
 }
 
-STATIC void UARTGenericIntHandler(uint32_t uart_id) {
+static void UARTGenericIntHandler(uint32_t uart_id) {
     pyb_uart_obj_t *self;
     uint32_t status;
 
@@ -272,22 +272,22 @@ STATIC void UARTGenericIntHandler(uint32_t uart_id) {
     self->irq_flags = 0;
 }
 
-STATIC void uart_check_init(pyb_uart_obj_t *self) {
+static void uart_check_init(pyb_uart_obj_t *self) {
     // not initialized
     if (!self->baudrate) {
         mp_raise_OSError(MP_EPERM);
     }
 }
 
-STATIC void UART0IntHandler(void) {
+static void UART0IntHandler(void) {
     UARTGenericIntHandler(0);
 }
 
-STATIC void UART1IntHandler(void) {
+static void UART1IntHandler(void) {
     UARTGenericIntHandler(1);
 }
 
-STATIC void uart_irq_enable (mp_obj_t self_in) {
+static void uart_irq_enable (mp_obj_t self_in) {
     pyb_uart_obj_t *self = self_in;
     // check for any of the rx interrupt types
     if (self->irq_trigger & (UART_TRIGGER_RX_ANY | UART_TRIGGER_RX_HALF | UART_TRIGGER_RX_FULL)) {
@@ -297,12 +297,12 @@ STATIC void uart_irq_enable (mp_obj_t self_in) {
     self->irq_enabled = true;
 }
 
-STATIC void uart_irq_disable (mp_obj_t self_in) {
+static void uart_irq_disable (mp_obj_t self_in) {
     pyb_uart_obj_t *self = self_in;
     self->irq_enabled = false;
 }
 
-STATIC int uart_irq_flags (mp_obj_t self_in) {
+static int uart_irq_flags (mp_obj_t self_in) {
     pyb_uart_obj_t *self = self_in;
     return self->irq_flags;
 }
@@ -310,7 +310,7 @@ STATIC int uart_irq_flags (mp_obj_t self_in) {
 /******************************************************************************/
 /* MicroPython bindings                                                      */
 
-STATIC void pyb_uart_print(const mp_print_t *print, mp_obj_t self_in, mp_print_kind_t kind) {
+static void pyb_uart_print(const mp_print_t *print, mp_obj_t self_in, mp_print_kind_t kind) {
     pyb_uart_obj_t *self = self_in;
     if (self->baudrate > 0) {
         mp_printf(print, "UART(%u, baudrate=%u, bits=", self->uart_id, self->baudrate);
@@ -342,7 +342,7 @@ STATIC void pyb_uart_print(const mp_print_t *print, mp_obj_t self_in, mp_print_k
     }
 }
 
-STATIC mp_obj_t pyb_uart_init_helper(pyb_uart_obj_t *self, const mp_arg_val_t *args) {
+static mp_obj_t pyb_uart_init_helper(pyb_uart_obj_t *self, const mp_arg_val_t *args) {
     // get the baudrate
     if (args[0].u_int <= 0) {
         goto error;
@@ -433,7 +433,7 @@ error:
     mp_raise_ValueError(MP_ERROR_TEXT("invalid argument(s) value"));
 }
 
-STATIC const mp_arg_t pyb_uart_init_args[] = {
+static const mp_arg_t pyb_uart_init_args[] = {
     { MP_QSTR_id,                             MP_ARG_OBJ,  {.u_obj = MP_OBJ_NULL} },
     { MP_QSTR_baudrate,                       MP_ARG_INT,  {.u_int = 9600} },
     { MP_QSTR_bits,                           MP_ARG_INT,  {.u_int = 8} },
@@ -441,7 +441,7 @@ STATIC const mp_arg_t pyb_uart_init_args[] = {
     { MP_QSTR_stop,                           MP_ARG_INT,  {.u_int = 1} },
     { MP_QSTR_pins,         MP_ARG_KW_ONLY  | MP_ARG_OBJ,  {.u_obj = MP_OBJ_NULL} },
 };
-STATIC mp_obj_t pyb_uart_make_new(const mp_obj_type_t *type, size_t n_args, size_t n_kw, const mp_obj_t *all_args) {
+static mp_obj_t pyb_uart_make_new(const mp_obj_type_t *type, size_t n_args, size_t n_kw, const mp_obj_t *all_args) {
     // parse args
     mp_map_t kw_args;
     mp_map_init_fixed_table(&kw_args, n_kw, all_args + n_args);
@@ -484,15 +484,15 @@ STATIC mp_obj_t pyb_uart_make_new(const mp_obj_type_t *type, size_t n_args, size
     return self;
 }
 
-STATIC mp_obj_t pyb_uart_init(size_t n_args, const mp_obj_t *pos_args, mp_map_t *kw_args) {
+static mp_obj_t pyb_uart_init(size_t n_args, const mp_obj_t *pos_args, mp_map_t *kw_args) {
     // parse args
     mp_arg_val_t args[MP_ARRAY_SIZE(pyb_uart_init_args) - 1];
     mp_arg_parse_all(n_args - 1, pos_args + 1, kw_args, MP_ARRAY_SIZE(args), &pyb_uart_init_args[1], args);
     return pyb_uart_init_helper(pos_args[0], args);
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_KW(pyb_uart_init_obj, 1, pyb_uart_init);
+static MP_DEFINE_CONST_FUN_OBJ_KW(pyb_uart_init_obj, 1, pyb_uart_init);
 
-STATIC mp_obj_t pyb_uart_deinit(mp_obj_t self_in) {
+static mp_obj_t pyb_uart_deinit(mp_obj_t self_in) {
     pyb_uart_obj_t *self = self_in;
 
     // unregister it with the sleep module
@@ -506,16 +506,16 @@ STATIC mp_obj_t pyb_uart_deinit(mp_obj_t self_in) {
     MAP_PRCMPeripheralClkDisable(self->peripheral, PRCM_RUN_MODE_CLK | PRCM_SLP_MODE_CLK);
     return mp_const_none;
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_1(pyb_uart_deinit_obj, pyb_uart_deinit);
+static MP_DEFINE_CONST_FUN_OBJ_1(pyb_uart_deinit_obj, pyb_uart_deinit);
 
-STATIC mp_obj_t pyb_uart_any(mp_obj_t self_in) {
+static mp_obj_t pyb_uart_any(mp_obj_t self_in) {
     pyb_uart_obj_t *self = self_in;
     uart_check_init(self);
     return mp_obj_new_int(uart_rx_any(self));
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_1(pyb_uart_any_obj, pyb_uart_any);
+static MP_DEFINE_CONST_FUN_OBJ_1(pyb_uart_any_obj, pyb_uart_any);
 
-STATIC mp_obj_t pyb_uart_sendbreak(mp_obj_t self_in) {
+static mp_obj_t pyb_uart_sendbreak(mp_obj_t self_in) {
     pyb_uart_obj_t *self = self_in;
     uart_check_init(self);
     // send a break signal for at least 2 complete frames
@@ -524,10 +524,10 @@ STATIC mp_obj_t pyb_uart_sendbreak(mp_obj_t self_in) {
     MAP_UARTBreakCtl(self->reg, false);
     return mp_const_none;
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_1(pyb_uart_sendbreak_obj, pyb_uart_sendbreak);
+static MP_DEFINE_CONST_FUN_OBJ_1(pyb_uart_sendbreak_obj, pyb_uart_sendbreak);
 
 /// \method irq(trigger, priority, handler, wake)
-STATIC mp_obj_t pyb_uart_irq(size_t n_args, const mp_obj_t *pos_args, mp_map_t *kw_args) {
+static mp_obj_t pyb_uart_irq(size_t n_args, const mp_obj_t *pos_args, mp_map_t *kw_args) {
     mp_arg_val_t args[mp_irq_INIT_NUM_ARGS];
     mp_arg_parse_all(n_args - 1, pos_args + 1, kw_args, mp_irq_INIT_NUM_ARGS, mp_irq_init_args, args);
 
@@ -556,9 +556,9 @@ STATIC mp_obj_t pyb_uart_irq(size_t n_args, const mp_obj_t *pos_args, mp_map_t *
 invalid_args:
     mp_raise_ValueError(MP_ERROR_TEXT("invalid argument(s) value"));
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_KW(pyb_uart_irq_obj, 1, pyb_uart_irq);
+static MP_DEFINE_CONST_FUN_OBJ_KW(pyb_uart_irq_obj, 1, pyb_uart_irq);
 
-STATIC mp_obj_t machine_uart_txdone(mp_obj_t self_in) {
+static mp_obj_t machine_uart_txdone(mp_obj_t self_in) {
     pyb_uart_obj_t *self = MP_OBJ_TO_PTR(self_in);
 
     if (MAP_UARTBusy(self->reg) == false) {
@@ -567,9 +567,9 @@ STATIC mp_obj_t machine_uart_txdone(mp_obj_t self_in) {
         return mp_const_false;
     }
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_1(machine_uart_txdone_obj, machine_uart_txdone);
+static MP_DEFINE_CONST_FUN_OBJ_1(machine_uart_txdone_obj, machine_uart_txdone);
 
-STATIC const mp_rom_map_elem_t pyb_uart_locals_dict_table[] = {
+static const mp_rom_map_elem_t pyb_uart_locals_dict_table[] = {
     // instance methods
     { MP_ROM_QSTR(MP_QSTR_init),        MP_ROM_PTR(&pyb_uart_init_obj) },
     { MP_ROM_QSTR(MP_QSTR_deinit),      MP_ROM_PTR(&pyb_uart_deinit_obj) },
@@ -590,11 +590,12 @@ STATIC const mp_rom_map_elem_t pyb_uart_locals_dict_table[] = {
 
     // class constants
     { MP_ROM_QSTR(MP_QSTR_RX_ANY),      MP_ROM_INT(UART_TRIGGER_RX_ANY) },
+    { MP_ROM_QSTR(MP_QSTR_IRQ_RX),      MP_ROM_INT(UART_TRIGGER_RX_ANY) },
 };
 
-STATIC MP_DEFINE_CONST_DICT(pyb_uart_locals_dict, pyb_uart_locals_dict_table);
+static MP_DEFINE_CONST_DICT(pyb_uart_locals_dict, pyb_uart_locals_dict_table);
 
-STATIC mp_uint_t pyb_uart_read(mp_obj_t self_in, void *buf_in, mp_uint_t size, int *errcode) {
+static mp_uint_t pyb_uart_read(mp_obj_t self_in, void *buf_in, mp_uint_t size, int *errcode) {
     pyb_uart_obj_t *self = self_in;
     byte *buf = buf_in;
     uart_check_init(self);
@@ -622,7 +623,7 @@ STATIC mp_uint_t pyb_uart_read(mp_obj_t self_in, void *buf_in, mp_uint_t size, i
     }
 }
 
-STATIC mp_uint_t pyb_uart_write(mp_obj_t self_in, const void *buf_in, mp_uint_t size, int *errcode) {
+static mp_uint_t pyb_uart_write(mp_obj_t self_in, const void *buf_in, mp_uint_t size, int *errcode) {
     pyb_uart_obj_t *self = self_in;
     const char *buf = buf_in;
     uart_check_init(self);
@@ -634,7 +635,7 @@ STATIC mp_uint_t pyb_uart_write(mp_obj_t self_in, const void *buf_in, mp_uint_t
     return size;
 }
 
-STATIC mp_uint_t pyb_uart_ioctl(mp_obj_t self_in, mp_uint_t request, mp_uint_t arg, int *errcode) {
+static mp_uint_t pyb_uart_ioctl(mp_obj_t self_in, mp_uint_t request, mp_uint_t arg, int *errcode) {
     pyb_uart_obj_t *self = self_in;
     mp_uint_t ret;
     uart_check_init(self);
@@ -670,14 +671,14 @@ STATIC mp_uint_t pyb_uart_ioctl(mp_obj_t self_in, mp_uint_t request, mp_uint_t a
     return ret;
 }
 
-STATIC const mp_stream_p_t uart_stream_p = {
+static const mp_stream_p_t uart_stream_p = {
     .read = pyb_uart_read,
     .write = pyb_uart_write,
     .ioctl = pyb_uart_ioctl,
     .is_text = false,
 };
 
-STATIC const mp_irq_methods_t uart_irq_methods = {
+static const mp_irq_methods_t uart_irq_methods = {
     .init = pyb_uart_irq,
     .enable = uart_irq_enable,
     .disable = uart_irq_disable,
