@@ -80,10 +80,10 @@
 /******************************************************************************
  DECLARE PRIVATE FUNCTIONS
  ******************************************************************************/
-STATIC void mptask_pre_init(void);
-STATIC void mptask_init_sflash_filesystem(void);
-STATIC void mptask_enter_ap_mode(void);
-STATIC void mptask_create_main_py(void);
+static void mptask_pre_init(void);
+static void mptask_init_sflash_filesystem(void);
+static void mptask_enter_ap_mode(void);
+static void mptask_create_main_py(void);
 
 /******************************************************************************
  DECLARE PUBLIC DATA
@@ -256,7 +256,7 @@ soft_reset_exit:
  DEFINE PRIVATE FUNCTIONS
  ******************************************************************************/
 __attribute__ ((section(".boot")))
-STATIC void mptask_pre_init(void) {
+static void mptask_pre_init(void) {
     // this one only makes sense after a poweron reset
     pyb_rtc_pre_init();
 
@@ -288,7 +288,7 @@ STATIC void mptask_pre_init(void) {
     ASSERT(svTaskHandle != NULL);
 }
 
-STATIC void mptask_init_sflash_filesystem(void) {
+static void mptask_init_sflash_filesystem(void) {
     FILINFO fno;
 
     // Initialise the local flash filesystem.
@@ -371,7 +371,7 @@ STATIC void mptask_init_sflash_filesystem(void) {
     }
 }
 
-STATIC void mptask_enter_ap_mode(void) {
+static void mptask_enter_ap_mode(void) {
     // append the mac only if it's not the first boot
     bool add_mac = !PRCMGetSpecialBit(PRCM_FIRST_BOOT_BIT);
     // enable simplelink in ap mode (use the MAC address to make the ssid unique)
@@ -380,7 +380,7 @@ STATIC void mptask_enter_ap_mode(void) {
         MICROPY_PORT_WLAN_AP_CHANNEL, ANTENNA_TYPE_INTERNAL, add_mac);
 }
 
-STATIC void mptask_create_main_py(void) {
+static void mptask_create_main_py(void) {
     // create empty main.py
     FIL fp;
     f_open(&sflash_vfs_fat->fatfs, &fp, "/main.py", FA_WRITE | FA_CREATE_ALWAYS);
