@@ -33,28 +33,26 @@
 #define DEFAULT_VREF 1100
 
 void madcblock_bits_helper(machine_adc_block_obj_t *self, mp_int_t bits) {
+    if (bits < SOC_ADC_RTC_MIN_BITWIDTH && bits > SOC_ADC_RTC_MAX_BITWIDTH) {
+        // Invalid value for the current chip, raise exception in the switch below.
+        bits = -1;
+    }
     switch (bits) {
-        #if CONFIG_IDF_TARGET_ESP32
         case 9:
-            self->width = ADC_WIDTH_BIT_9;
+            self->width = ADC_BITWIDTH_9;
             break;
         case 10:
-            self->width = ADC_WIDTH_BIT_10;
+            self->width = ADC_BITWIDTH_10;
             break;
         case 11:
-            self->width = ADC_WIDTH_BIT_11;
+            self->width = ADC_BITWIDTH_11;
             break;
-        #endif
-        #if CONFIG_IDF_TARGET_ESP32 || CONFIG_IDF_TARGET_ESP32C3 || CONFIG_IDF_TARGET_ESP32C6 || CONFIG_IDF_TARGET_ESP32S3
         case 12:
-            self->width = ADC_WIDTH_BIT_12;
+            self->width = ADC_BITWIDTH_12;
             break;
-        #endif
-        #if CONFIG_IDF_TARGET_ESP32S2
         case 13:
-            self->width = ADC_WIDTH_BIT_13;
+            self->width = ADC_BITWIDTH_13;
             break;
-        #endif
         default:
             mp_raise_ValueError(MP_ERROR_TEXT("invalid bits"));
     }
