@@ -156,7 +156,13 @@ static void pwm_deinit(int channel_idx) {
         int timer_idx = chans[channel_idx].timer_idx;
         if (timer_idx != -1) {
             if (!is_timer_in_use(channel_idx, timer_idx)) {
-                check_esp_err(ledc_timer_rst(TIMER_IDX_TO_MODE(timer_idx), TIMER_IDX_TO_TIMER(timer_idx)));
+                check_esp_err(ledc_timer_pause(TIMER_IDX_TO_MODE(timer_idx), TIMER_IDX_TO_TIMER(timer_idx)));
+                ledc_timer_config_t timer_config = {
+                    .deconfigure = true,
+                    .speed_mode = TIMER_IDX_TO_MODE(timer_idx),
+                    .timer_num = TIMER_IDX_TO_TIMER(timer_idx),
+                };
+                check_esp_err(ledc_timer_config(&timer_config));
                 // Flag it unused
                 timers[chans[channel_idx].timer_idx].freq_hz = -1;
             }
@@ -211,39 +217,6 @@ static void configure_channel(machine_pwm_obj_t *self) {
     }
 }
 
-// Temporary workaround for ledc_find_suitable_duty_resolution function only being added in IDF V5.2
-#if ESP_IDF_VERSION < ESP_IDF_VERSION_VAL(5, 2, 0)
-static uint32_t ledc_find_suitable_duty_resolution(uint32_t src_clk_freq, uint32_t timer_freq) {
-    // This implementation is based on the one used in Micropython v1.23
-
-    // Find the highest bit resolution for the requested frequency
-    unsigned int freq = src_clk_freq;
-
-    int divider = (freq + timer_freq / 2) / timer_freq; // rounded
-    if (divider == 0) {
-        divider = 1;
-    }
-    float f = (float)freq / divider; // actual frequency
-    if (f <= 1.0) {
-        f = 1.0;
-    }
-    freq = (unsigned int)roundf((float)freq / f);
-
-    unsigned int res = 0;
-    for (; freq > 1; freq >>= 1) {
-        ++res;
-    }
-    if (res == 0) {
-        res = 1;
-    } else if (res > HIGHEST_PWM_RES) {
-        // Limit resolution to HIGHEST_PWM_RES to match units of our duty
-        res = HIGHEST_PWM_RES;
-    }
-
-    return res;
-}
-#endif
-
 static void set_freq(machine_pwm_obj_t *self, unsigned int freq, ledc_timer_config_t *timer) {
     esp_err_t err;
     if (freq != timer->freq_hz) {
@@ -265,20 +238,10 @@ static void set_freq(machine_pwm_obj_t *self, unsigned int freq, ledc_timer_conf
         }
         #endif
         uint32_t src_clk_freq = 0;
-        #if ESP_IDF_VERSION >= ESP_IDF_VERSION_VAL(5, 1, 0)
         err = esp_clk_tree_src_get_freq_hz(timer->clk_cfg, ESP_CLK_TREE_SRC_FREQ_PRECISION_CACHED, &src_clk_freq);
         if (err != ESP_OK) {
             mp_raise_msg_varg(&mp_type_ValueError, MP_ERROR_TEXT("unable to query source clock frequency %d"), (int)timer->clk_cfg);
         }
-        #else
-        // Simplified fallback logic for IDF V5.0.x, for targets with APB only.
-        src_clk_freq = APB_CLK_FREQ; // 80 MHz
-        #if SOC_LEDC_SUPPORT_REF_TICK
-        if (timer->clk_cfg == LEDC_USE_REF_TICK) {
-            src_clk_freq = REF_CLK_FREQ; // 1 MHz
-        }
-        #endif // SOC_LEDC_SUPPORT_REF_TICK
-        #endif // ESP_IDF_VERSION
 
         timer->duty_resolution = ledc_find_suitable_duty_resolution(src_clk_freq, timer->freq_hz);
 
@@ -678,7 +641,13 @@ static void mp_machine_pwm_freq_set(machine_pwm_obj_t *self, mp_int_t freq) {
 
         if (!current_in_use) {
             // Free the old timer
-            check_esp_err(ledc_timer_rst(self->mode, self->timer));
+            check_esp_err(ledc_timer_pause(self->mode, self->timer));
+            ledc_timer_config_t timer_config = {
+                .deconfigure = true,
+                .speed_mode = self->mode,
+                .timer_num = self->timer,
+            };
+            check_esp_err(ledc_timer_config(&timer_config));
             // Flag it unused
             timers[current_timer_idx].freq_hz = -1;
         }
