@@ -399,11 +399,7 @@ static void mp_machine_uart_init_helper(machine_uart_obj_t *self, size_t n_args,
         }
         self->flowcontrol = args[ARG_flow].u_int;
     }
-    #if ESP_IDF_VERSION >= ESP_IDF_VERSION_VAL(5, 2, 0)
     uint8_t uart_fifo_len = UART_HW_FIFO_LEN(self->uart_num);
-    #else
-    uint8_t uart_fifo_len = UART_FIFO_LEN;
-    #endif
     check_esp_err(uart_set_hw_flow_ctrl(self->uart_num, self->flowcontrol, uart_fifo_len - uart_fifo_len / 4));
 }
 
