@@ -26,9 +26,10 @@
 #ifndef MICROPY_INCLUDED_ESP32_MODNETWORK_H
 #define MICROPY_INCLUDED_ESP32_MODNETWORK_H
 
-#include "esp_event.h"
+#include "esp_netif.h"
 
-enum { PHY_LAN8720, PHY_IP101, PHY_RTL8201, PHY_DP83848, PHY_KSZ8041 };
+enum { PHY_LAN8710, PHY_LAN8720, PHY_IP101, PHY_RTL8201, PHY_DP83848, PHY_KSZ8041, PHY_KSZ8081, PHY_KSZ8851SNL = 100, PHY_DM9051, PHY_W5500 };
+#define IS_SPI_PHY(NUM) (NUM >= 100)
 enum { ETH_INITIALIZED, ETH_STARTED, ETH_STOPPED, ETH_CONNECTED, ETH_DISCONNECTED, ETH_GOT_IP };
 
 // Cases similar to ESP8266 user_interface.h
@@ -39,16 +40,26 @@ enum {
     STAT_GOT_IP     = 1010,
 };
 
-typedef struct _wlan_if_obj_t {
+typedef struct _base_if_obj_t {
     mp_obj_base_t base;
-    int if_id;
-} wlan_if_obj_t;
+    esp_interface_t if_id;
+    esp_netif_t *netif;
+    volatile bool active;
+} base_if_obj_t;
 
-MP_DECLARE_CONST_FUN_OBJ_VAR_BETWEEN(get_wlan_obj);
-MP_DECLARE_CONST_FUN_OBJ_KW(get_lan_obj);
-MP_DECLARE_CONST_FUN_OBJ_1(ppp_make_new_obj);
-MP_DECLARE_CONST_FUN_OBJ_VAR_BETWEEN(esp_ifconfig_obj);
-MP_DECLARE_CONST_FUN_OBJ_KW(esp_config_obj);
+extern const mp_obj_type_t esp_network_wlan_type;
+
+MP_DECLARE_CONST_FUN_OBJ_0(esp_network_initialize_obj);
+MP_DECLARE_CONST_FUN_OBJ_VAR_BETWEEN(esp_network_get_wlan_obj);
+MP_DECLARE_CONST_FUN_OBJ_KW(esp_network_get_lan_obj);
+MP_DECLARE_CONST_FUN_OBJ_1(esp_network_ppp_make_new_obj);
+MP_DECLARE_CONST_FUN_OBJ_VAR_BETWEEN(esp_network_ifconfig_obj);
+MP_DECLARE_CONST_FUN_OBJ_KW(esp_network_ipconfig_obj);
+MP_DECLARE_CONST_FUN_OBJ_KW(esp_nic_ipconfig_obj);
+MP_DECLARE_CONST_FUN_OBJ_KW(esp_network_config_obj);
+MP_DECLARE_CONST_FUN_OBJ_VAR_BETWEEN(esp_network_phy_mode_obj);
+
+mp_obj_t esp_ifname(esp_netif_t *netif);
 
 NORETURN void esp_exceptions_helper(esp_err_t e);
 
@@ -58,7 +69,7 @@ static inline void esp_exceptions(esp_err_t e) {
     }
 }
 
-void usocket_events_deinit(void);
-void network_wlan_event_handler(system_event_t *event);
+void socket_events_deinit(void);
+void esp_initialise_wifi(void);
 
 #endif
