@@ -1,4 +1,4 @@
-import uos
+import vfs
 from flashbdev import bdev
 
 
@@ -17,6 +17,10 @@ def check_bootsec():
 
 def fs_corrupted():
     import time
+    import micropython
+
+    # Allow this loop to be stopped via Ctrl-C.
+    micropython.kbd_intr(3)
 
     while 1:
         print(
@@ -33,9 +37,13 @@ by firmware programming).
 def setup():
     check_bootsec()
     print("Performing initial setup")
-    uos.VfsLfs2.mkfs(bdev)
-    vfs = uos.VfsLfs2(bdev)
-    uos.mount(vfs, "/")
+    if bdev.info()[4] == "vfs":
+        vfs.VfsLfs2.mkfs(bdev)
+        fs = vfs.VfsLfs2(bdev)
+    elif bdev.info()[4] == "ffat":
+        vfs.VfsFat.mkfs(bdev)
+        fs = vfs.VfsFat(bdev)
+    vfs.mount(fs, "/")
     with open("boot.py", "w") as f:
         f.write(
             """\
@@ -46,4 +54,4 @@ def setup():
 #webrepl.start()
 """
         )
-    return vfs
+    return fs
