@@ -107,7 +107,7 @@
 #endif
 
 #if MICROPY_HW_ENABLE_RF_SWITCH
-#define CYW43_PIN_WL_RFSW_VDD           pin_WL_RFSW_VDD
+#define CYW43_PIN_RFSW_VDD              pin_WL_RFSW_VDD
 #endif
 
 #define cyw43_schedule_internal_poll_dispatch(func) pendsv_schedule_dispatch(PENDSV_DISPATCH_CYW43, func)
