@@ -33,6 +33,7 @@
 #include "py/nlr.h"
 #include "py/runtime.h"
 #include "py/mphal.h"
+#include "py/gc.h"
 #include "pin.h"
 #include "nrf_gpio.h"
 #include "nrfx_gpiote.h"
@@ -107,7 +108,7 @@ extern const uint8_t machine_pin_num_of_board_pins;
 
 // Pin class variables
 #if PIN_DEBUG
-STATIC bool pin_class_debug;
+static bool pin_class_debug;
 #else
 #define pin_class_debug (0)
 #endif
@@ -218,7 +219,7 @@ const pin_obj_t *pin_find(mp_obj_t user_obj) {
 
 /// \method __str__()
 /// Return a string describing the pin object.
-STATIC void pin_print(const mp_print_t *print, mp_obj_t self_in, mp_print_kind_t kind) {
+static void pin_print(const mp_print_t *print, mp_obj_t self_in, mp_print_kind_t kind) {
     pin_obj_t *self = self_in;
 
     char *pull = "PULL_DISABLED";
@@ -234,17 +235,17 @@ STATIC void pin_print(const mp_print_t *print, mp_obj_t self_in, mp_print_kind_t
     }
 
     mp_printf(print, "Pin(%d, mode=%s, pull=%s)",
-            self->pin,
-            (nrf_gpio_pin_dir_get(self->pin) == NRF_GPIO_PIN_DIR_OUTPUT) ? "OUT" : "IN",
-            pull);
+        self->pin,
+        (nrf_gpio_pin_dir_get(self->pin) == NRF_GPIO_PIN_DIR_OUTPUT) ? "OUT" : "IN",
+        pull);
 }
 
-STATIC mp_obj_t pin_obj_init_helper(const pin_obj_t *pin, mp_uint_t n_args, const mp_obj_t *args, mp_map_t *kw_args);
+static mp_obj_t pin_obj_init_helper(const pin_obj_t *pin, mp_uint_t n_args, const mp_obj_t *args, mp_map_t *kw_args);
 
 /// \classmethod \constructor(id, ...)
 /// Create a new Pin object associated with the id.  If additional arguments are given,
 /// they are used to initialise the pin.  See `init`.
-STATIC mp_obj_t pin_make_new(const mp_obj_type_t *type, mp_uint_t n_args, mp_uint_t n_kw, const mp_obj_t *args) {
+static mp_obj_t pin_make_new(const mp_obj_type_t *type, mp_uint_t n_args, mp_uint_t n_kw, const mp_obj_t *args) {
     mp_arg_check_num(n_args, n_kw, 1, MP_OBJ_FUN_ARGS_MAX, true);
 
     // Run an argument through the mapper and return the result.
@@ -261,7 +262,7 @@ STATIC mp_obj_t pin_make_new(const mp_obj_type_t *type, mp_uint_t n_args, mp_uin
 }
 
 // fast method for getting/setting pin value
-STATIC mp_obj_t pin_call(mp_obj_t self_in, mp_uint_t n_args, mp_uint_t n_kw, const mp_obj_t *args) {
+static mp_obj_t pin_call(mp_obj_t self_in, mp_uint_t n_args, mp_uint_t n_kw, const mp_obj_t *args) {
     mp_arg_check_num(n_args, n_kw, 0, 1, false);
     pin_obj_t *self = self_in;
     if (n_args == 0) {
@@ -274,47 +275,47 @@ STATIC mp_obj_t pin_call(mp_obj_t self_in, mp_uint_t n_args, mp_uint_t n_kw, con
     }
 }
 
-STATIC mp_obj_t pin_off(mp_obj_t self_in) {
+static mp_obj_t pin_off(mp_obj_t self_in) {
     pin_obj_t *self = self_in;
     mp_hal_pin_low(self);
     return mp_const_none;
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_1(pin_off_obj, pin_off);
+static MP_DEFINE_CONST_FUN_OBJ_1(pin_off_obj, pin_off);
 
-STATIC mp_obj_t pin_on(mp_obj_t self_in) {
+static mp_obj_t pin_on(mp_obj_t self_in) {
     pin_obj_t *self = self_in;
     mp_hal_pin_high(self);
     return mp_const_none;
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_1(pin_on_obj, pin_on);
+static MP_DEFINE_CONST_FUN_OBJ_1(pin_on_obj, pin_on);
 
 /// \classmethod mapper([fun])
 /// Get or set the pin mapper function.
-STATIC mp_obj_t pin_mapper(mp_uint_t n_args, const mp_obj_t *args) {
+static mp_obj_t pin_mapper(mp_uint_t n_args, const mp_obj_t *args) {
     if (n_args > 1) {
         MP_STATE_PORT(pin_class_mapper) = args[1];
         return mp_const_none;
     }
     return MP_STATE_PORT(pin_class_mapper);
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_VAR_BETWEEN(pin_mapper_fun_obj, 1, 2, pin_mapper);
-STATIC MP_DEFINE_CONST_CLASSMETHOD_OBJ(pin_mapper_obj, (mp_obj_t)&pin_mapper_fun_obj);
+static MP_DEFINE_CONST_FUN_OBJ_VAR_BETWEEN(pin_mapper_fun_obj, 1, 2, pin_mapper);
+static MP_DEFINE_CONST_CLASSMETHOD_OBJ(pin_mapper_obj, (mp_obj_t)&pin_mapper_fun_obj);
 
 /// \classmethod dict([dict])
 /// Get or set the pin mapper dictionary.
-STATIC mp_obj_t pin_map_dict(mp_uint_t n_args, const mp_obj_t *args) {
+static mp_obj_t pin_map_dict(mp_uint_t n_args, const mp_obj_t *args) {
     if (n_args > 1) {
         MP_STATE_PORT(pin_class_map_dict) = args[1];
         return mp_const_none;
     }
     return MP_STATE_PORT(pin_class_map_dict);
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_VAR_BETWEEN(pin_map_dict_fun_obj, 1, 2, pin_map_dict);
-STATIC MP_DEFINE_CONST_CLASSMETHOD_OBJ(pin_map_dict_obj, (mp_obj_t)&pin_map_dict_fun_obj);
+static MP_DEFINE_CONST_FUN_OBJ_VAR_BETWEEN(pin_map_dict_fun_obj, 1, 2, pin_map_dict);
+static MP_DEFINE_CONST_CLASSMETHOD_OBJ(pin_map_dict_obj, (mp_obj_t)&pin_map_dict_fun_obj);
 
 /// \classmethod af_list()
 /// Returns an array of alternate functions available for this pin.
-STATIC mp_obj_t pin_af_list(mp_obj_t self_in) {
+static mp_obj_t pin_af_list(mp_obj_t self_in) {
     pin_obj_t *self = self_in;
     mp_obj_t result = mp_obj_new_list(0, NULL);
 
@@ -324,24 +325,24 @@ STATIC mp_obj_t pin_af_list(mp_obj_t self_in) {
     }
     return result;
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_1(pin_af_list_obj, pin_af_list);
+static MP_DEFINE_CONST_FUN_OBJ_1(pin_af_list_obj, pin_af_list);
 
 #if PIN_DEBUG
 /// \classmethod debug([state])
 /// Get or set the debugging state (`True` or `False` for on or off).
-STATIC mp_obj_t pin_debug(mp_uint_t n_args, const mp_obj_t *args) {
+static mp_obj_t pin_debug(mp_uint_t n_args, const mp_obj_t *args) {
     if (n_args > 1) {
         pin_class_debug = mp_obj_is_true(args[1]);
         return mp_const_none;
     }
     return mp_obj_new_bool(pin_class_debug);
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_VAR_BETWEEN(pin_debug_fun_obj, 1, 2, pin_debug);
-STATIC MP_DEFINE_CONST_CLASSMETHOD_OBJ(pin_debug_obj, (mp_obj_t)&pin_debug_fun_obj);
+static MP_DEFINE_CONST_FUN_OBJ_VAR_BETWEEN(pin_debug_fun_obj, 1, 2, pin_debug);
+static MP_DEFINE_CONST_CLASSMETHOD_OBJ(pin_debug_obj, (mp_obj_t)&pin_debug_fun_obj);
 #endif
 
 // init(mode, pull=None, af=-1, *, value, alt)
-STATIC mp_obj_t pin_obj_init_helper(const pin_obj_t *self, mp_uint_t n_args, const mp_obj_t *pos_args, mp_map_t *kw_args) {
+static mp_obj_t pin_obj_init_helper(const pin_obj_t *self, mp_uint_t n_args, const mp_obj_t *pos_args, mp_map_t *kw_args) {
     static const mp_arg_t allowed_args[] = {
         { MP_QSTR_mode, MP_ARG_REQUIRED | MP_ARG_INT },
         { MP_QSTR_pull, MP_ARG_OBJ, {.u_obj = mp_const_none}},
@@ -375,11 +376,11 @@ STATIC mp_obj_t pin_obj_init_helper(const pin_obj_t *self, mp_uint_t n_args, con
 
     if (mode == NRF_GPIO_PIN_DIR_OUTPUT || mode == NRF_GPIO_PIN_DIR_INPUT) {
         nrf_gpio_cfg(self->pin,
-                     mode,
-                     input,
-                     pull,
-                     NRF_GPIO_PIN_S0S1,
-                     NRF_GPIO_PIN_NOSENSE);
+            mode,
+            input,
+            pull,
+            NRF_GPIO_PIN_S0S1,
+            NRF_GPIO_PIN_NOSENSE);
     } else {
         mp_raise_msg_varg(&mp_type_ValueError, MP_ERROR_TEXT("invalid pin mode: %d"), mode);
     }
@@ -387,7 +388,7 @@ STATIC mp_obj_t pin_obj_init_helper(const pin_obj_t *self, mp_uint_t n_args, con
     return mp_const_none;
 }
 
-STATIC mp_obj_t pin_obj_init(mp_uint_t n_args, const mp_obj_t *args, mp_map_t *kw_args) {
+static mp_obj_t pin_obj_init(mp_uint_t n_args, const mp_obj_t *args, mp_map_t *kw_args) {
     return pin_obj_init_helper(args[0], n_args - 1, args + 1, kw_args);
 }
 MP_DEFINE_CONST_FUN_OBJ_KW(pin_init_obj, 1, pin_obj_init);
@@ -399,40 +400,40 @@ MP_DEFINE_CONST_FUN_OBJ_KW(pin_init_obj, 1, pin_obj_init);
 ///   - With `value` given, set the logic level of the pin.  `value` can be
 ///   anything that converts to a boolean.  If it converts to `True`, the pin
 ///   is set high, otherwise it is set low.
-STATIC mp_obj_t pin_value(mp_uint_t n_args, const mp_obj_t *args) {
+static mp_obj_t pin_value(mp_uint_t n_args, const mp_obj_t *args) {
     return pin_call(args[0], n_args - 1, 0, args + 1);
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_VAR_BETWEEN(pin_value_obj, 1, 2, pin_value);
+static MP_DEFINE_CONST_FUN_OBJ_VAR_BETWEEN(pin_value_obj, 1, 2, pin_value);
 
 /// \method low()
 /// Set the pin to a low logic level.
-STATIC mp_obj_t pin_low(mp_obj_t self_in) {
+static mp_obj_t pin_low(mp_obj_t self_in) {
     pin_obj_t *self = self_in;
     mp_hal_pin_low(self);
     return mp_const_none;
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_1(pin_low_obj, pin_low);
+static MP_DEFINE_CONST_FUN_OBJ_1(pin_low_obj, pin_low);
 
 /// \method high()
 /// Set the pin to a high logic level.
-STATIC mp_obj_t pin_high(mp_obj_t self_in) {
+static mp_obj_t pin_high(mp_obj_t self_in) {
     pin_obj_t *self = self_in;
     mp_hal_pin_high(self);
     return mp_const_none;
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_1(pin_high_obj, pin_high);
+static MP_DEFINE_CONST_FUN_OBJ_1(pin_high_obj, pin_high);
 
 /// \method name()
 /// Get the pin name.
-STATIC mp_obj_t pin_name(mp_obj_t self_in) {
+static mp_obj_t pin_name(mp_obj_t self_in) {
     pin_obj_t *self = self_in;
     return MP_OBJ_NEW_QSTR(self->name);
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_1(pin_name_obj, pin_name);
+static MP_DEFINE_CONST_FUN_OBJ_1(pin_name_obj, pin_name);
 
 /// \method names()
 /// Returns the cpu and board names for this pin.
-STATIC mp_obj_t pin_names(mp_obj_t self_in) {
+static mp_obj_t pin_names(mp_obj_t self_in) {
     pin_obj_t *self = self_in;
     mp_obj_t result = mp_obj_new_list(0, NULL);
     mp_obj_list_append(result, MP_OBJ_NEW_QSTR(self->name));
@@ -447,61 +448,83 @@ STATIC mp_obj_t pin_names(mp_obj_t self_in) {
     }
     return result;
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_1(pin_names_obj, pin_names);
+static MP_DEFINE_CONST_FUN_OBJ_1(pin_names_obj, pin_names);
 
 /// \method port()
 /// Get the pin port.
-STATIC mp_obj_t pin_port(mp_obj_t self_in) {
+static mp_obj_t pin_port(mp_obj_t self_in) {
     pin_obj_t *self = self_in;
     return MP_OBJ_NEW_SMALL_INT(self->pin / 32);
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_1(pin_port_obj, pin_port);
+static MP_DEFINE_CONST_FUN_OBJ_1(pin_port_obj, pin_port);
 
 /// \method pin()
 /// Get the pin number.
-STATIC mp_obj_t pin_pin(mp_obj_t self_in) {
+static mp_obj_t pin_pin(mp_obj_t self_in) {
     pin_obj_t *self = self_in;
     return MP_OBJ_NEW_SMALL_INT(self->pin);
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_1(pin_pin_obj, pin_pin);
+static MP_DEFINE_CONST_FUN_OBJ_1(pin_pin_obj, pin_pin);
 
 /// \method mode()
 /// Returns the currently configured mode of the pin. The integer returned
 /// will match one of the allowed constants for the mode argument to the init
 /// function.
-STATIC mp_obj_t pin_mode(mp_obj_t self_in) {
+static mp_obj_t pin_mode(mp_obj_t self_in) {
     return mp_const_none; // TODO: MP_OBJ_NEW_SMALL_INT(pin_get_mode(self_in));
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_1(pin_mode_obj, pin_mode);
+static MP_DEFINE_CONST_FUN_OBJ_1(pin_mode_obj, pin_mode);
 
 /// \method pull()
 /// Returns the currently configured pull of the pin. The integer returned
 /// will match one of the allowed constants for the pull argument to the init
 /// function.
-STATIC mp_obj_t pin_pull(mp_obj_t self_in) {
+static mp_obj_t pin_pull(mp_obj_t self_in) {
     return mp_const_none; // TODO: MP_OBJ_NEW_SMALL_INT(pin_get_pull(self_in));
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_1(pin_pull_obj, pin_pull);
+static MP_DEFINE_CONST_FUN_OBJ_1(pin_pull_obj, pin_pull);
 
 /// \method af()
 /// Returns the currently configured alternate-function of the pin. The
 /// integer returned will match one of the allowed constants for the af
 /// argument to the init function.
-STATIC mp_obj_t pin_af(mp_obj_t self_in) {
+static mp_obj_t pin_af(mp_obj_t self_in) {
     return mp_const_none; // TODO: MP_OBJ_NEW_SMALL_INT(pin_get_af(self_in));
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_1(pin_af_obj, pin_af);
+static MP_DEFINE_CONST_FUN_OBJ_1(pin_af_obj, pin_af);
 
 
-STATIC void pin_common_irq_handler(nrfx_gpiote_pin_t pin, nrf_gpiote_polarity_t action) {
+static void pin_common_irq_handler(nrfx_gpiote_pin_t pin, nrf_gpiote_polarity_t action) {
     mp_obj_t pin_handler = MP_STATE_PORT(pin_irq_handlers)[pin];
     mp_obj_t pin_number = MP_OBJ_NEW_SMALL_INT(pin);
-    const pin_obj_t *pin_obj  = pin_find(pin_number);
+    const pin_obj_t *pin_obj = pin_find(pin_number);
 
-    mp_call_function_1(pin_handler, (mp_obj_t)pin_obj);
+    if (pin_handler != mp_const_none) {
+        #if MICROPY_ENABLE_SCHEDULER
+        mp_sched_lock();
+        #endif
+        // When executing code within a handler we must lock the GC to prevent
+        // any memory allocations.  We must also catch any exceptions.
+        gc_lock();
+        nlr_buf_t nlr;
+        if (nlr_push(&nlr) == 0) {
+            mp_call_function_1(pin_handler, (mp_obj_t)pin_obj);
+            nlr_pop();
+        } else {
+            // Uncaught exception; disable the callback so it doesn't run again.
+            MP_STATE_PORT(pin_irq_handlers)[pin] = mp_const_none;
+            nrfx_gpiote_in_uninit(pin);
+            mp_printf(MICROPY_ERROR_PRINTER, "uncaught exception in interrupt handler for Pin('%q')\n", pin_obj->name);
+            mp_obj_print_exception(&mp_plat_print, MP_OBJ_FROM_PTR(nlr.ret_val));
+        }
+        gc_unlock();
+        #if MICROPY_ENABLE_SCHEDULER
+        mp_sched_unlock();
+        #endif
+    }
 }
 
-STATIC mp_obj_t pin_irq(size_t n_args, const mp_obj_t *pos_args, mp_map_t *kw_args) {
+static mp_obj_t pin_irq(size_t n_args, const mp_obj_t *pos_args, mp_map_t *kw_args) {
     enum {ARG_handler, ARG_trigger, ARG_wake};
     static const mp_arg_t allowed_args[] = {
         { MP_QSTR_handler, MP_ARG_OBJ | MP_ARG_REQUIRED,  {.u_obj = mp_const_none} },
@@ -514,19 +537,24 @@ STATIC mp_obj_t pin_irq(size_t n_args, const mp_obj_t *pos_args, mp_map_t *kw_ar
 
     nrfx_gpiote_pin_t pin = self->pin;
 
-    nrfx_gpiote_in_config_t config = NRFX_GPIOTE_CONFIG_IN_SENSE_TOGGLE(true);
-    if (args[ARG_trigger].u_int == NRF_GPIOTE_POLARITY_LOTOHI) {
-        config.sense = NRF_GPIOTE_POLARITY_LOTOHI;
-    } else if (args[ARG_trigger].u_int == NRF_GPIOTE_POLARITY_HITOLO) {
-        config.sense = NRF_GPIOTE_POLARITY_HITOLO;
-    }
-    config.pull = NRF_GPIO_PIN_PULLUP;
+    if (args[ARG_handler].u_obj != mp_const_none) {
+        nrfx_gpiote_in_config_t config = NRFX_GPIOTE_CONFIG_IN_SENSE_TOGGLE(true);
+        if (args[ARG_trigger].u_int == NRF_GPIOTE_POLARITY_LOTOHI) {
+            config.sense = NRF_GPIOTE_POLARITY_LOTOHI;
+        } else if (args[ARG_trigger].u_int == NRF_GPIOTE_POLARITY_HITOLO) {
+            config.sense = NRF_GPIOTE_POLARITY_HITOLO;
+        }
+        config.pull = NRF_GPIO_PIN_PULLUP;
+        config.skip_gpio_setup = true;
 
-    nrfx_err_t err_code = nrfx_gpiote_in_init(pin, &config, pin_common_irq_handler);
-    if (err_code == NRFX_ERROR_INVALID_STATE) {
-        // Re-init if already configured.
+        nrfx_err_t err_code = nrfx_gpiote_in_init(pin, &config, pin_common_irq_handler);
+        if (err_code == NRFX_ERROR_INVALID_STATE) {
+            // Re-init if already configured.
+            nrfx_gpiote_in_uninit(pin);
+            nrfx_gpiote_in_init(pin, &config, pin_common_irq_handler);
+        }
+    } else {
         nrfx_gpiote_in_uninit(pin);
-        nrfx_gpiote_in_init(pin, &config, pin_common_irq_handler);
     }
 
     MP_STATE_PORT(pin_irq_handlers)[pin] = args[ARG_handler].u_obj;
@@ -536,9 +564,9 @@ STATIC mp_obj_t pin_irq(size_t n_args, const mp_obj_t *pos_args, mp_map_t *kw_ar
     // return the irq object
     return mp_const_none;
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_KW(pin_irq_obj, 1, pin_irq);
+static MP_DEFINE_CONST_FUN_OBJ_KW(pin_irq_obj, 1, pin_irq);
 
-STATIC const mp_rom_map_elem_t pin_locals_dict_table[] = {
+static const mp_rom_map_elem_t pin_locals_dict_table[] = {
     // instance methods
     { MP_ROM_QSTR(MP_QSTR_init),    MP_ROM_PTR(&pin_init_obj) },
     { MP_ROM_QSTR(MP_QSTR_value),   MP_ROM_PTR(&pin_value_obj) },
@@ -591,10 +619,10 @@ STATIC const mp_rom_map_elem_t pin_locals_dict_table[] = {
     { MP_ROM_QSTR(MP_QSTR_AF_OD),     MP_ROM_INT(GPIO_MODE_AF_OD) },
     { MP_ROM_QSTR(MP_QSTR_PULL_NONE), MP_ROM_INT(GPIO_NOPULL) },
 */
-#include "genhdr/pins_af_const.h"
+    #include "genhdr/pins_af_const.h"
 };
 
-STATIC MP_DEFINE_CONST_DICT(pin_locals_dict, pin_locals_dict_table);
+static MP_DEFINE_CONST_DICT(pin_locals_dict, pin_locals_dict_table);
 
 MP_DEFINE_CONST_OBJ_TYPE(
     pin_type,
@@ -635,42 +663,42 @@ MP_DEFINE_CONST_OBJ_TYPE(
 
 /// \method __str__()
 /// Return a string describing the alternate function.
-STATIC void pin_af_obj_print(const mp_print_t *print, mp_obj_t self_in, mp_print_kind_t kind) {
+static void pin_af_obj_print(const mp_print_t *print, mp_obj_t self_in, mp_print_kind_t kind) {
     pin_af_obj_t *self = self_in;
     mp_printf(print, "Pin.%q", self->name);
 }
 
 /// \method index()
 /// Return the alternate function index.
-STATIC mp_obj_t pin_af_index(mp_obj_t self_in) {
+static mp_obj_t pin_af_index(mp_obj_t self_in) {
     pin_af_obj_t *af = self_in;
     return MP_OBJ_NEW_SMALL_INT(af->idx);
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_1(pin_af_index_obj, pin_af_index);
+static MP_DEFINE_CONST_FUN_OBJ_1(pin_af_index_obj, pin_af_index);
 
 /// \method name()
 /// Return the name of the alternate function.
-STATIC mp_obj_t pin_af_name(mp_obj_t self_in) {
+static mp_obj_t pin_af_name(mp_obj_t self_in) {
     pin_af_obj_t *af = self_in;
     return MP_OBJ_NEW_QSTR(af->name);
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_1(pin_af_name_obj, pin_af_name);
+static MP_DEFINE_CONST_FUN_OBJ_1(pin_af_name_obj, pin_af_name);
 
 /// \method reg()
 /// Return the base register associated with the peripheral assigned to this
 /// alternate function.
-STATIC mp_obj_t pin_af_reg(mp_obj_t self_in) {
+static mp_obj_t pin_af_reg(mp_obj_t self_in) {
     pin_af_obj_t *af = self_in;
     return MP_OBJ_NEW_SMALL_INT((mp_uint_t)af->reg);
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_1(pin_af_reg_obj, pin_af_reg);
+static MP_DEFINE_CONST_FUN_OBJ_1(pin_af_reg_obj, pin_af_reg);
 
-STATIC const mp_rom_map_elem_t pin_af_locals_dict_table[] = {
+static const mp_rom_map_elem_t pin_af_locals_dict_table[] = {
     { MP_ROM_QSTR(MP_QSTR_index),   MP_ROM_PTR(&pin_af_index_obj) },
     { MP_ROM_QSTR(MP_QSTR_name),    MP_ROM_PTR(&pin_af_name_obj) },
     { MP_ROM_QSTR(MP_QSTR_reg),     MP_ROM_PTR(&pin_af_reg_obj) },
 };
-STATIC MP_DEFINE_CONST_DICT(pin_af_locals_dict, pin_af_locals_dict_table);
+static MP_DEFINE_CONST_DICT(pin_af_locals_dict, pin_af_locals_dict_table);
 
 MP_DEFINE_CONST_OBJ_TYPE(
     pin_af_type,
