@@ -33,13 +33,13 @@
 #include "modubluepy.h"
 #include "ble_drv.h"
 
-STATIC void ubluepy_service_print(const mp_print_t *print, mp_obj_t o, mp_print_kind_t kind) {
+static void ubluepy_service_print(const mp_print_t *print, mp_obj_t o, mp_print_kind_t kind) {
     ubluepy_service_obj_t * self = (ubluepy_service_obj_t *)o;
 
     mp_printf(print, "Service(handle: 0x" HEX2_FMT ")", self->handle);
 }
 
-STATIC mp_obj_t ubluepy_service_make_new(const mp_obj_type_t *type, size_t n_args, size_t n_kw, const mp_obj_t *all_args) {
+static mp_obj_t ubluepy_service_make_new(const mp_obj_type_t *type, size_t n_args, size_t n_kw, const mp_obj_t *all_args) {
 
     enum { ARG_NEW_UUID, ARG_NEW_TYPE };
 
@@ -86,7 +86,7 @@ STATIC mp_obj_t ubluepy_service_make_new(const mp_obj_type_t *type, size_t n_arg
 /// \method addCharacteristic(Characteristic)
 /// Add Characteristic to the Service.
 ///
-STATIC mp_obj_t service_add_characteristic(mp_obj_t self_in, mp_obj_t characteristic) {
+static mp_obj_t service_add_characteristic(mp_obj_t self_in, mp_obj_t characteristic) {
     ubluepy_service_obj_t        * self   = MP_OBJ_TO_PTR(self_in);
     ubluepy_characteristic_obj_t * p_char = MP_OBJ_TO_PTR(characteristic);
 
@@ -103,22 +103,22 @@ STATIC mp_obj_t service_add_characteristic(mp_obj_t self_in, mp_obj_t characteri
     // return mp_obj_new_bool(retval);
     return mp_const_none;
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_2(ubluepy_service_add_char_obj, service_add_characteristic);
+static MP_DEFINE_CONST_FUN_OBJ_2(ubluepy_service_add_char_obj, service_add_characteristic);
 
 /// \method getCharacteristics()
 /// Return list with all characteristics registered in the Service.
 ///
-STATIC mp_obj_t service_get_chars(mp_obj_t self_in) {
+static mp_obj_t service_get_chars(mp_obj_t self_in) {
     ubluepy_service_obj_t * self = MP_OBJ_TO_PTR(self_in);
 
     return self->char_list;
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_1(ubluepy_service_get_chars_obj, service_get_chars);
+static MP_DEFINE_CONST_FUN_OBJ_1(ubluepy_service_get_chars_obj, service_get_chars);
 
 /// \method getCharacteristic(UUID)
 /// Return Characteristic with the given UUID.
 ///
-STATIC mp_obj_t service_get_characteristic(mp_obj_t self_in, mp_obj_t uuid) {
+static mp_obj_t service_get_characteristic(mp_obj_t self_in, mp_obj_t uuid) {
     ubluepy_service_obj_t * self   = MP_OBJ_TO_PTR(self_in);
     ubluepy_uuid_obj_t    * p_uuid = MP_OBJ_TO_PTR(uuid);
 
@@ -145,18 +145,18 @@ STATIC mp_obj_t service_get_characteristic(mp_obj_t self_in, mp_obj_t uuid) {
 
     return mp_const_none;
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_2(ubluepy_service_get_char_obj, service_get_characteristic);
+static MP_DEFINE_CONST_FUN_OBJ_2(ubluepy_service_get_char_obj, service_get_characteristic);
 
 /// \method uuid()
 /// Get UUID instance of the Service.
 ///
-STATIC mp_obj_t service_uuid(mp_obj_t self_in) {
+static mp_obj_t service_uuid(mp_obj_t self_in) {
     ubluepy_service_obj_t * self = MP_OBJ_TO_PTR(self_in);
     return MP_OBJ_FROM_PTR(self->p_uuid);
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_1(ubluepy_service_get_uuid_obj, service_uuid);
+static MP_DEFINE_CONST_FUN_OBJ_1(ubluepy_service_get_uuid_obj, service_uuid);
 
-STATIC const mp_rom_map_elem_t ubluepy_service_locals_dict_table[] = {
+static const mp_rom_map_elem_t ubluepy_service_locals_dict_table[] = {
     { MP_ROM_QSTR(MP_QSTR_getCharacteristic),  MP_ROM_PTR(&ubluepy_service_get_char_obj) },
     { MP_ROM_QSTR(MP_QSTR_addCharacteristic),  MP_ROM_PTR(&ubluepy_service_add_char_obj) },
     { MP_ROM_QSTR(MP_QSTR_getCharacteristics), MP_ROM_PTR(&ubluepy_service_get_chars_obj) },
@@ -169,7 +169,7 @@ STATIC const mp_rom_map_elem_t ubluepy_service_locals_dict_table[] = {
     { MP_ROM_QSTR(MP_QSTR_SECONDARY),  MP_ROM_INT(UBLUEPY_SERVICE_SECONDARY) },
 };
 
-STATIC MP_DEFINE_CONST_DICT(ubluepy_service_locals_dict, ubluepy_service_locals_dict_table);
+static MP_DEFINE_CONST_DICT(ubluepy_service_locals_dict, ubluepy_service_locals_dict_table);
 
 MP_DEFINE_CONST_OBJ_TYPE(
     ubluepy_service_type,
