@@ -28,10 +28,12 @@
 #define __NRF52_HAL
 
 #include "py/mpconfig.h"
+#include "py/ringbuf.h"
 #include <nrfx.h>
 #include "pin.h"
 #include "nrf_gpio.h"
 #include "nrfx_config.h"
+#include "shared/runtime/interrupt_char.h"
 
 typedef enum
 {
@@ -43,17 +45,25 @@ typedef enum
 
 extern const unsigned char mp_hal_status_to_errno_table[4];
 
+extern ringbuf_t stdin_ringbuf;
+
 NORETURN void mp_hal_raise(HAL_StatusTypeDef status);
 void mp_hal_set_interrupt_char(int c); // -1 to disable
 
 int mp_hal_stdin_rx_chr(void);
 void mp_hal_stdout_tx_str(const char *str);
 
+static inline void mp_hal_wake_main_task_from_isr(void) {
+    // Defined for tinyusb support, nothing needs to be done here.
+}
+
 void mp_hal_delay_ms(mp_uint_t ms);
 void mp_hal_delay_us(mp_uint_t us);
 
 const char *nrfx_error_code_lookup(uint32_t err_code);
 
+void mp_nrf_start_lfclk(void);
+
 #define MP_HAL_PIN_FMT           "%q"
 #define mp_hal_pin_obj_t const pin_obj_t *
 #define mp_hal_get_pin_obj(o)    pin_find(o)
