@@ -30,28 +30,28 @@
 #include "py/mphal.h"
 #include "modpyb.h"
 
-STATIC mp_obj_t pyb_millis(void) {
+static mp_obj_t pyb_millis(void) {
     return MP_OBJ_NEW_SMALL_INT(mp_hal_ticks_ms());
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_0(pyb_millis_obj, pyb_millis);
+static MP_DEFINE_CONST_FUN_OBJ_0(pyb_millis_obj, pyb_millis);
 
-STATIC mp_obj_t pyb_elapsed_millis(mp_obj_t start) {
+static mp_obj_t pyb_elapsed_millis(mp_obj_t start) {
     uint32_t startMillis = mp_obj_get_int(start);
     uint32_t currMillis = mp_hal_ticks_ms();
     return MP_OBJ_NEW_SMALL_INT((currMillis - startMillis) & 0x1fff);
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_1(pyb_elapsed_millis_obj, pyb_elapsed_millis);
+static MP_DEFINE_CONST_FUN_OBJ_1(pyb_elapsed_millis_obj, pyb_elapsed_millis);
 
-STATIC mp_obj_t pyb_delay(mp_obj_t ms_in) {
+static mp_obj_t pyb_delay(mp_obj_t ms_in) {
     mp_int_t ms = mp_obj_get_int(ms_in);
     if (ms >= 0) {
         mp_hal_delay_ms(ms);
     }
     return mp_const_none;
 }
-STATIC MP_DEFINE_CONST_FUN_OBJ_1(pyb_delay_obj, pyb_delay);
+static MP_DEFINE_CONST_FUN_OBJ_1(pyb_delay_obj, pyb_delay);
 
-STATIC const mp_rom_map_elem_t pyb_module_globals_table[] = {
+static const mp_rom_map_elem_t pyb_module_globals_table[] = {
     { MP_ROM_QSTR(MP_QSTR___name__), MP_ROM_QSTR(MP_QSTR_pyb) },
 
     { MP_ROM_QSTR(MP_QSTR_millis), MP_ROM_PTR(&pyb_millis_obj) },
@@ -62,7 +62,7 @@ STATIC const mp_rom_map_elem_t pyb_module_globals_table[] = {
     { MP_ROM_QSTR(MP_QSTR_Switch), MP_ROM_PTR(&pyb_switch_type) },
 };
 
-STATIC MP_DEFINE_CONST_DICT(pyb_module_globals, pyb_module_globals_table);
+static MP_DEFINE_CONST_DICT(pyb_module_globals, pyb_module_globals_table);
 
 const mp_obj_module_t pyb_module = {
     .base = { &mp_type_module },
