@@ -7,13 +7,6 @@
 #define MICROPY_HW_USB_VID (0x239A)
 #define MICROPY_HW_USB_PID (0x80FE)
 
-#define MICROPY_HW_I2C0_SCL  (3)
-#define MICROPY_HW_I2C0_SDA  (2)
-
-#define MICROPY_HW_SPI0_SCK  (18)
-#define MICROPY_HW_SPI0_MOSI (19)
-#define MICROPY_HW_SPI0_MISO (20)
-
 // NeoPixel data GPIO17, power GPIO16
 
 // Red user LED GPIO11
