@@ -1,4 +1,4 @@
-import os
+import vfs
 import machine, rp2
 
 
@@ -6,10 +6,10 @@ import machine, rp2
 # Note: the flash requires the programming size to be aligned to 256 bytes.
 bdev = rp2.Flash()
 try:
-    vfs = os.VfsLfs2(bdev, progsize=256)
+    fs = vfs.VfsLfs2(bdev, progsize=256)
 except:
-    os.VfsLfs2.mkfs(bdev, progsize=256)
-    vfs = os.VfsLfs2(bdev, progsize=256)
-os.mount(vfs, "/")
+    vfs.VfsLfs2.mkfs(bdev, progsize=256)
+    fs = vfs.VfsLfs2(bdev, progsize=256)
+vfs.mount(fs, "/")
 
-del os, bdev, vfs
+del vfs, bdev, fs
