@@ -4,4 +4,8 @@
 #define MICROPY_HW_XOSC32K          (1)
 #define MICROPY_HW_MCU_OSC32KULP    (1)
 
+#define MICROPY_HW_DEFAULT_UART_ID  (5)
+#define MICROPY_HW_DEFAULT_I2C_ID   (2)
+#define MICROPY_HW_DEFAULT_SPI_ID   (1)
+
 #define MICROPY_HW_QSPIFLASH        GD25Q16C
