@@ -3,5 +3,9 @@
 
 #define MICROPY_HW_DFLL_USB_SYNC    (1)
 
+#define MICROPY_HW_DEFAULT_SPI_ID   (4)
+#define MICROPY_HW_DEFAULT_I2C_ID   (3)
+#define MICROPY_HW_DEFAULT_UART_ID  (0)
+
 #define MICROPY_HW_SPIFLASH         (1)
 #define MICROPY_HW_SPIFLASH_ID      (5)
