@@ -3,6 +3,10 @@
 
 #define MICROPY_HW_XOSC32K          (1)
 
+#define MICROPY_HW_DEFAULT_UART_ID  (2)
+#define MICROPY_HW_DEFAULT_I2C_ID   (3)
+#define MICROPY_HW_DEFAULT_SPI_ID   (4)
+
 // There seems to be an inconsistency in the SAMD51 Thing bootloader in that
 // the bootloader magic address is at the end of a 192k RAM area, instead of
 // 256k. Since the SAMD51x20A has 256k RAM, the loader symbol is at that address
