@@ -40,6 +40,12 @@
 #define MICROPY_HW_UART_REPL_BAUD   115200
 
 // I2C buses
+#define MICROPY_HW_I2C1_SCL (pin_B8)  // Pin 2 on CN7
+#define MICROPY_HW_I2C1_SDA (pin_B9)  // Pin 4 on CN7
+
+#define MICROPY_HW_I2C2_SCL (pin_B10) // Pin 32 on CN10
+#define MICROPY_HW_I2C2_SDA (pin_B11) // Pin 34 on CN10
+
 #define MICROPY_HW_I2C3_SCL (pin_A8)
 #define MICROPY_HW_I2C3_SDA (pin_C9)
 
