@@ -29,12 +29,12 @@
 
 #if MICROPY_HW_SPIFLASH_ENABLE_CACHE
 // Shared cache for first and second SPI block devices
-STATIC mp_spiflash_cache_t spi_bdev_cache;
+static mp_spiflash_cache_t spi_bdev_cache;
 #endif
 
 // First external SPI flash uses software QSPI interface
 
-STATIC const mp_soft_qspi_obj_t soft_qspi_bus = {
+static const mp_soft_qspi_obj_t soft_qspi_bus = {
     .cs = MICROPY_HW_SPIFLASH_CS,
     .clk = MICROPY_HW_SPIFLASH_SCK,
     .io0 = MICROPY_HW_SPIFLASH_IO0,
