@@ -5,6 +5,7 @@
 #define MICROPY_HW_HAS_FLASH        (1)
 #define MICROPY_HW_ENABLE_RNG       (1)
 #define MICROPY_HW_ENABLE_RTC       (1)
+#define MICROPY_HW_ENABLE_DAC       (1)
 #define MICROPY_HW_ENABLE_USB       (1)
 #define MICROPY_HW_ENABLE_SERVO     (1)
 
@@ -99,6 +100,7 @@
 
 #define MICROPY_HW_SDRAM_BURST_LENGTH       2
 #define MICROPY_HW_SDRAM_CAS_LATENCY        3
+#define MICROPY_HW_SDRAM_FREQUENCY_KHZ      (90000) // 90 MHz
 #define MICROPY_HW_SDRAM_COLUMN_BITS_NUM    8
 #define MICROPY_HW_SDRAM_ROW_BITS_NUM       12
 #define MICROPY_HW_SDRAM_MEM_BUS_WIDTH      16
@@ -108,6 +110,7 @@
 #define MICROPY_HW_SDRAM_RBURST             (0)
 #define MICROPY_HW_SDRAM_WRITE_PROTECTION   (0)
 #define MICROPY_HW_SDRAM_AUTOREFRESH_NUM    (4)
+#define MICROPY_HW_SDRAM_REFRESH_CYCLES     8192
 
 #define MICROPY_HW_FMC_SDCKE1   (pin_B5)
 #define MICROPY_HW_FMC_SDNE1    (pin_B6)
