@@ -26,39 +26,6 @@
 #ifndef MICROPY_INCLUDED_STM32H7XX_HAL_CONF_BASE_H
 #define MICROPY_INCLUDED_STM32H7XX_HAL_CONF_BASE_H
 
-// Include various HAL modules for convenience
-#include "stm32h7xx_hal_dma.h"
-#include "stm32h7xx_hal_mdma.h"
-#include "stm32h7xx_hal_adc.h"
-#include "stm32h7xx_hal_cortex.h"
-#include "stm32h7xx_hal_crc.h"
-#include "stm32h7xx_hal_dac.h"
-#include "stm32h7xx_hal_dcmi.h"
-#include "stm32h7xx_hal_fdcan.h"
-#include "stm32h7xx_hal_flash.h"
-#include "stm32h7xx_hal_gpio.h"
-#include "stm32h7xx_hal_hash.h"
-#include "stm32h7xx_hal_hcd.h"
-#include "stm32h7xx_hal_i2c.h"
-#include "stm32h7xx_hal_i2s.h"
-#include "stm32h7xx_hal_iwdg.h"
-#include "stm32h7xx_hal_pcd.h"
-#include "stm32h7xx_hal_pwr.h"
-#include "stm32h7xx_hal_rcc.h"
-#include "stm32h7xx_hal_rtc.h"
-#include "stm32h7xx_hal_sd.h"
-#include "stm32h7xx_hal_sdram.h"
-#include "stm32h7xx_hal_spi.h"
-#include "stm32h7xx_hal_tim.h"
-#include "stm32h7xx_hal_uart.h"
-#include "stm32h7xx_hal_usart.h"
-#include "stm32h7xx_hal_wwdg.h"
-#include "stm32h7xx_ll_adc.h"
-#include "stm32h7xx_ll_lpuart.h"
-#include "stm32h7xx_ll_pwr.h"
-#include "stm32h7xx_ll_rtc.h"
-#include "stm32h7xx_ll_usart.h"
-
 // Enable various HAL modules
 #define HAL_ADC_MODULE_ENABLED
 #define HAL_CORTEX_MODULE_ENABLED
@@ -98,7 +65,47 @@
 #define USE_SD_TRANSCEIVER  0
 #define USE_SPI_CRC         1
 
+// Include various HAL modules for convenience
+#include "stm32h7xx_hal_dma.h"
+#include "stm32h7xx_hal_mdma.h"
+#include "stm32h7xx_hal_adc.h"
+#include "stm32h7xx_hal_cortex.h"
+#include "stm32h7xx_hal_crc.h"
+#include "stm32h7xx_hal_dac.h"
+#include "stm32h7xx_hal_dcmi.h"
+#include "stm32h7xx_hal_fdcan.h"
+#include "stm32h7xx_hal_flash.h"
+#include "stm32h7xx_hal_gpio.h"
+#include "stm32h7xx_hal_hash.h"
+#include "stm32h7xx_hal_hcd.h"
+#include "stm32h7xx_hal_i2c.h"
+#include "stm32h7xx_hal_i2s.h"
+#include "stm32h7xx_hal_iwdg.h"
+#include "stm32h7xx_hal_pcd.h"
+#include "stm32h7xx_hal_pwr.h"
+#include "stm32h7xx_hal_rcc.h"
+#include "stm32h7xx_hal_rtc.h"
+#include "stm32h7xx_hal_sd.h"
+#include "stm32h7xx_hal_sdram.h"
+#include "stm32h7xx_hal_spi.h"
+#include "stm32h7xx_hal_tim.h"
+#include "stm32h7xx_hal_uart.h"
+#include "stm32h7xx_hal_usart.h"
+#include "stm32h7xx_hal_wwdg.h"
+#include "stm32h7xx_ll_adc.h"
+#include "stm32h7xx_ll_lpuart.h"
+#include "stm32h7xx_ll_pwr.h"
+#include "stm32h7xx_ll_rcc.h"
+#include "stm32h7xx_ll_rtc.h"
+#include "stm32h7xx_ll_usart.h"
+
 // HAL parameter assertions are disabled
 #define assert_param(expr) ((void)0)
 
+// The STM32H7xx HAL defines LPUART1 AF macros without numbers.
+#ifndef GPIO_AF3_LPUART1
+#define GPIO_AF3_LPUART1 GPIO_AF3_LPUART
+#define GPIO_AF8_LPUART1 GPIO_AF8_LPUART
+#endif
+
 #endif // MICROPY_INCLUDED_STM32H7XX_HAL_CONF_BASE_H
