@@ -84,7 +84,7 @@ void pyb_thread_deinit() {
     enable_irq(irq_state);
 }
 
-STATIC void pyb_thread_terminate(void) {
+static void pyb_thread_terminate(void) {
     uint32_t irq_state = disable_irq();
     pyb_thread_t *thread = pyb_thread_cur;
     // take current thread off the run list
