@@ -3,7 +3,7 @@
  *
  * The MIT License (MIT)
  *
- * Copyright (c) 2013, 2014 Damien P. George
+ * Copyright (c) 2013-2023 Damien P. George
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -31,6 +31,7 @@
 
 #include <limits.h>
 #include <assert.h>
+#include <stdbool.h>
 
 #include "py/mpconfig.h"
 
@@ -40,8 +41,11 @@
 #define MICROPY_NLR_NUM_REGS_ARM_THUMB      (10)
 #define MICROPY_NLR_NUM_REGS_ARM_THUMB_FP   (10 + 6)
 #define MICROPY_NLR_NUM_REGS_AARCH64        (13)
+#define MICROPY_NLR_NUM_REGS_MIPS           (13)
 #define MICROPY_NLR_NUM_REGS_XTENSA         (10)
 #define MICROPY_NLR_NUM_REGS_XTENSAWIN      (17)
+#define MICROPY_NLR_NUM_REGS_RV32I          (14)
+#define MICROPY_NLR_NUM_REGS_RV64I          (14)
 
 // *FORMAT-OFF*
 
@@ -83,6 +87,19 @@
     #define MICROPY_NLR_POWERPC (1)
     // this could be less but using 128 for safety
     #define MICROPY_NLR_NUM_REGS (128)
+#elif defined(__mips__)
+    #define MICROPY_NLR_MIPS (1)
+    #define MICROPY_NLR_NUM_REGS (MICROPY_NLR_NUM_REGS_MIPS)
+#elif defined(__riscv)
+    #if __riscv_xlen == 32
+        #define MICROPY_NLR_NUM_REGS (MICROPY_NLR_NUM_REGS_RV32I)
+        #define MICROPY_NLR_RV32I (1)
+    #elif __riscv_xlen == 64
+        #define MICROPY_NLR_NUM_REGS (MICROPY_NLR_NUM_REGS_RV64I)
+        #define MICROPY_NLR_RV64I (1)
+    #else
+        #error Unsupported RISC-V variant.
+    #endif
 #else
     #define MICROPY_NLR_SETJMP (1)
     //#warning "No native NLR support for this arch, using setjmp implementation"
@@ -97,9 +114,16 @@
 
 typedef struct _nlr_buf_t nlr_buf_t;
 struct _nlr_buf_t {
-    // the entries here must all be machine word size
+    // The entries in this struct must all be machine word size.
+
+    // Pointer to the previous nlr_buf_t in the chain.
+    // Or NULL if it's the top-level one.
     nlr_buf_t *prev;
-    void *ret_val; // always a concrete object (an exception instance)
+
+    // The exception that is being raised:
+    // - NULL means the jump is because of a VM abort (only if MICROPY_ENABLE_VM_ABORT enabled)
+    // - otherwise it's always a concrete object (an exception instance)
+    void *ret_val;
 
     #if MICROPY_NLR_SETJMP
     jmp_buf jmpbuf;
@@ -112,6 +136,15 @@ struct _nlr_buf_t {
     #endif
 };
 
+typedef void (*nlr_jump_callback_fun_t)(void *ctx);
+
+typedef struct _nlr_jump_callback_node_t nlr_jump_callback_node_t;
+
+struct _nlr_jump_callback_node_t {
+    nlr_jump_callback_node_t *prev;
+    nlr_jump_callback_fun_t fun;
+};
+
 // Helper macros to save/restore the pystack state
 #if MICROPY_ENABLE_PYSTACK
 #define MP_NLR_SAVE_PYSTACK(nlr_buf) (nlr_buf)->pystack = MP_STATE_THREAD(pystack_cur)
@@ -129,6 +162,7 @@ struct _nlr_buf_t {
         nlr_jump_fail(val); \
     } \
     top->ret_val = val; \
+    nlr_call_jump_callbacks(top); \
     MP_NLR_RESTORE_PYSTACK(top); \
     *_top_ptr = top->prev; \
 
@@ -145,6 +179,12 @@ unsigned int nlr_push_tail(nlr_buf_t *top);
 void nlr_pop(void);
 NORETURN void nlr_jump(void *val);
 
+#if MICROPY_ENABLE_VM_ABORT
+#define nlr_set_abort(buf) MP_STATE_VM(nlr_abort) = buf
+#define nlr_get_abort() MP_STATE_VM(nlr_abort)
+NORETURN void nlr_jump_abort(void);
+#endif
+
 // This must be implemented by a port.  It's called by nlr_jump
 // if no nlr buf has been pushed.  It must not return, but rather
 // should bail out with a fatal error.
@@ -154,11 +194,9 @@ NORETURN void nlr_jump_fail(void *val);
 #ifndef MICROPY_DEBUG_NLR
 #define nlr_raise(val) nlr_jump(MP_OBJ_TO_PTR(val))
 #else
-#include "mpstate.h"
+
 #define nlr_raise(val) \
     do { \
-        /*printf("nlr_raise: nlr_top=%p\n", MP_STATE_THREAD(nlr_top)); \
-        fflush(stdout);*/ \
         void *_val = MP_OBJ_TO_PTR(val); \
         assert(_val != NULL); \
         assert(mp_obj_is_exception_instance(val)); \
@@ -168,13 +206,20 @@ NORETURN void nlr_jump_fail(void *val);
 #if !MICROPY_NLR_SETJMP
 #define nlr_push(val) \
     assert(MP_STATE_THREAD(nlr_top) != val), nlr_push(val)
-
-/*
-#define nlr_push(val) \
-    printf("nlr_push: before: nlr_top=%p, val=%p\n", MP_STATE_THREAD(nlr_top), val),assert(MP_STATE_THREAD(nlr_top) != val),nlr_push(val)
-*/
 #endif
 
 #endif
 
+// Push a callback on to the linked-list of NLR jump callbacks.  The `node` pointer must
+// be on the C stack.  The `fun` callback will be executed if an NLR jump is taken which
+// unwinds the C stack through this `node`.
+void nlr_push_jump_callback(nlr_jump_callback_node_t *node, nlr_jump_callback_fun_t fun);
+
+// Pop a callback from the linked-list of NLR jump callbacks.  The corresponding function
+// will be called if `run_callback` is true.
+void nlr_pop_jump_callback(bool run_callback);
+
+// Pop and call all NLR jump callbacks that were registered after `nlr` buffer was pushed.
+void nlr_call_jump_callbacks(nlr_buf_t *nlr);
+
 #endif // MICROPY_INCLUDED_PY_NLR_H
