@@ -76,6 +76,9 @@ typedef struct _scope_t {
     struct _scope_t *next;
     mp_parse_node_t pn;
     mp_raw_code_t *raw_code;
+    #if MICROPY_DEBUG_PRINTERS
+    size_t raw_code_data_len; // for mp_bytecode_print
+    #endif
     uint16_t simple_name; // a qstr
     uint16_t scope_flags;  // see runtime0.h
     uint16_t emit_options; // see emitglue.h
