@@ -4,12 +4,10 @@ description: JSON module does not throw exception when object is not serialisabl
 cause: Unknown
 workaround: Unknown
 """
+
 import json
 
-a = bytes(x for x in range(256))
 try:
-    z = json.dumps(a)
-    x = json.loads(z)
-    print("Should not get here")
+    print(json.dumps(b"shouldn't be able to serialise bytes"))
 except TypeError:
     print("TypeError")
