@@ -1,10 +1,8 @@
 # test machine.Signal class
 
 try:
-    try:
-        import umachine as machine
-    except ImportError:
-        import machine
+    import machine
+
     machine.PinBase
     machine.Signal
 except:
