@@ -1,19 +1,13 @@
 try:
-    import uerrno
-    import uos
-except ImportError:
-    print("SKIP")
-    raise SystemExit
+    import errno, os, vfs
 
-try:
-    uos.VfsFat
-except AttributeError:
+    vfs.VfsFat
+except (ImportError, AttributeError):
     print("SKIP")
     raise SystemExit
 
 
 class RAMFS_OLD:
-
     SEC_SIZE = 512
 
     def __init__(self, blocks):
@@ -42,18 +36,18 @@ except MemoryError:
     print("SKIP")
     raise SystemExit
 
-uos.VfsFat.mkfs(bdev)
-vfs = uos.VfsFat(bdev)
-uos.mount(vfs, "/ramdisk")
+vfs.VfsFat.mkfs(bdev)
+fs = vfs.VfsFat(bdev)
+vfs.mount(fs, "/ramdisk")
 
 # file io
-with vfs.open("file.txt", "w") as f:
+with fs.open("file.txt", "w") as f:
     f.write("hello!")
 
-print(list(vfs.ilistdir()))
+print(list(fs.ilistdir()))
 
-with vfs.open("file.txt", "r") as f:
+with fs.open("file.txt", "r") as f:
     print(f.read())
 
-vfs.remove("file.txt")
-print(list(vfs.ilistdir()))
+fs.remove("file.txt")
+print(list(fs.ilistdir()))
