@@ -1,20 +1,20 @@
-f = open("io/data/file1")
+f = open("data/file1")
 print(f.read(5))
 print(f.readline())
 print(f.read())
-f = open("io/data/file1")
+f = open("data/file1")
 print(f.readlines())
-f = open("io/data/file1", "r")
+f = open("data/file1", "r")
 print(f.readlines())
-f = open("io/data/file1", "rb")
+f = open("data/file1", "rb")
 print(f.readlines())
-f = open("io/data/file1", mode="r")
+f = open("data/file1", mode="r")
 print(f.readlines())
-f = open("io/data/file1", mode="rb")
+f = open("data/file1", mode="rb")
 print(f.readlines())
 
 # write() error
-f = open("io/data/file1", "r")
+f = open("data/file1", "r")
 try:
     f.write("x")
 except OSError:
@@ -22,7 +22,7 @@ except OSError:
 f.close()
 
 # read(n) error on binary file
-f = open("io/data/file1", "ab")
+f = open("data/file1", "ab")
 try:
     f.read(1)
 except OSError:
@@ -30,7 +30,7 @@ except OSError:
 f.close()
 
 # read(n) error on text file
-f = open("io/data/file1", "at")
+f = open("data/file1", "at")
 try:
     f.read(1)
 except OSError:
@@ -38,7 +38,7 @@ except OSError:
 f.close()
 
 # read() w/o args error
-f = open("io/data/file1", "ab")
+f = open("data/file1", "ab")
 try:
     f.read()
 except OSError:
