@@ -9,8 +9,6 @@ try:
 except AttributeError:
     pass
 
-a = set()
-
 
 def test():
     micropython.heap_lock()
@@ -21,8 +19,8 @@ def test():
         print(type(e).__name__, e)
 
     try:
-        a.pop()
-    except KeyError as e:
+        raise 0
+    except TypeError as e:
         print(type(e).__name__, e)
 
     try:
@@ -31,8 +29,8 @@ def test():
         print(e.args[0])
 
     try:
-        a.pop()
-    except KeyError as e:
+        raise 0
+    except TypeError as e:
         print(e.args[0])
 
     micropython.heap_unlock()
