@@ -21,7 +21,7 @@ def memsum(src: ptr8, n: int) -> int:
 
 
 # create array and get its address
-ar = bytearray("0000")
+ar = bytearray(b"0000")
 addr = get_addr(ar)
 print(type(ar))
 print(type(addr))
