@@ -8,15 +8,12 @@ import re
 from glob import glob
 from collections import defaultdict
 
-# Tests require at least CPython 3.3. If your default python3 executable
-# is of lower version, you can point MICROPY_CPYTHON3 environment var
-# to the correct executable.
 if os.name == "nt":
-    CPYTHON3 = os.getenv("MICROPY_CPYTHON3", "python3.exe")
-    MICROPYTHON = os.getenv("MICROPY_MICROPYTHON", "../ports/windows/micropython.exe")
+    MICROPYTHON = os.getenv(
+        "MICROPY_MICROPYTHON", "../ports/windows/build-standard/micropython.exe"
+    )
 else:
-    CPYTHON3 = os.getenv("MICROPY_CPYTHON3", "python3")
-    MICROPYTHON = os.getenv("MICROPY_MICROPYTHON", "../ports/unix/micropython")
+    MICROPYTHON = os.getenv("MICROPY_MICROPYTHON", "../ports/unix/build-standard/micropython")
 
 
 def run_tests(pyb, test_dict):
@@ -26,7 +23,6 @@ def run_tests(pyb, test_dict):
     for base_test, tests in sorted(test_dict.items()):
         print(base_test + ":")
         for test_file in tests:
-
             # run MicroPython
             if pyb is None:
                 # run on PC
