@@ -25,7 +25,12 @@ n_finished = 0
 
 # spawn threads
 for i in range(n_thread):
-    _thread.start_new_thread(thread_entry, ())
+    while True:
+        try:
+            _thread.start_new_thread(thread_entry, ())
+            break
+        except OSError:
+            pass
 
 # busy wait for threads to finish
 while n_finished < n_thread:
